package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.MaintenanceDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.MaintenanceDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.MaintenanceDataRequest;
import cn.com.ty.lift.batch.applet.util.DataStatisticsUtil;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class MaintenanceDataService {

    @Resource
    private MaintenanceDataMapper maintenanceDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间 终止时间
     * @return
     * @description 将维保数据放入redis中
     * @date 2020/2/4 1:50 下午
     */
    public void putMaintenanceDataListToRedis(CommonRequest commonRequest) {
        List<MaintenanceDataModel> maintenanceDataModelList = maintenanceDataMapper.getMaintenanceDataList(commonRequest);
        //通过公司id对数据进行分组,并将维保数据放入redis中
        DataStatisticsUtil.putStatisticsDataToRedis(maintenanceDataModelList, redisTemplate,
                DataStatisticsConstants.MAINTENANCE_DATA_FIELD);
    }

    /**
     * @param
     * @return
     * @description 将维保数据从redis中取出来
     * @date 2020/2/4 2:04 下午
     */
    public List<MaintenanceDataModel> getMaintenanceDataListFromRedis(MaintenanceDataRequest maintenanceDataRequest) {
        //从redis中获取当前公司维保数据
        List<MaintenanceDataModel> maintenanceDataModelList = (List<MaintenanceDataModel>) DataStatisticsUtil
                .getStatisticsDataFromRedis(redisTemplate, DataStatisticsConstants.MAINTENANCE_DATA_FIELD,
                        maintenanceDataRequest.getMtCompanyId());
        return maintenanceDataModelList;
    }

    /**
     * @param
     * @return
     * @description 获取维保统计总览情况
     * @date 2020/2/5 4:50 下午
     */
    public RestResponse maintenanceOverView(MaintenanceDataRequest maintenanceDataRequest) {
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }

    /**
     * @param
     * @return
     * @description 超期统计
     * @date 2020/2/5 4:53 下午
     */
    public RestResponse beyondStatistics(MaintenanceDataRequest maintenanceDataRequest) {
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }
}
